You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ode.apache.org by mr...@apache.org on 2006/07/27 23:52:07 UTC

svn commit: r426260 [19/23] - in /incubator/ode/scratch/pxe-iapi: ./ axis2-examples/src/examples/DynPartner/ axis2-examples/src/examples/HelloWorld2/ axis2-examples/src/examples/MagicSession/ axis2-war/ axis2-war/src/main/webapp/WEB-INF/ axis2-war/src/...

Modified: incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnection.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnection.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionFactoryImpl.java (original)
+++ incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionFactoryImpl.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.ra;
+package org.apache.ode.ra;
 
 import javax.naming.NamingException;
 import javax.naming.Reference;
@@ -17,14 +17,14 @@
 
 /**
  */
-class PxeConnectionFactoryImpl implements PxeConnectionFactory {
+class OdeConnectionFactoryImpl implements OdeConnectionFactory {
   private static final long serialVersionUID = 1L;
   
   private Reference _reference;
   private ConnectionManager _manager;
   private ManagedConnectionFactory _managedConnectionFactory;
 
-  PxeConnectionFactoryImpl(ManagedConnectionFactory mcf, ConnectionManager manager) {
+  OdeConnectionFactoryImpl(ManagedConnectionFactory mcf, ConnectionManager manager) {
     _manager = manager;
     _managedConnectionFactory = mcf;
   }

Modified: incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionImpl.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionImpl.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionImpl.java (original)
+++ incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionImpl.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.ra;
+package org.apache.ode.ra;
 
 import java.lang.reflect.InvocationHandler;
 import java.lang.reflect.InvocationTargetException;
@@ -20,22 +20,22 @@
 import javax.resource.spi.ConnectionRequestInfo;
 import javax.security.auth.Subject;
 
-import com.fs.utils.ObjectPrinter;
-import com.fs.utils.Reflect;
+import org.apache.ode.utils.ObjectPrinter;
+import org.apache.ode.utils.Reflect;
 
 /**
  */
-class PxeConnectionImpl implements InvocationHandler, Connection {
+class OdeConnectionImpl implements InvocationHandler, Connection {
 
   private final Subject _subject;
 
   private final ConnectionRequestInfo _cri;
 
-  private PxeManagedConnectionImpl _managedConnection;
+  private OdeManagedConnectionImpl _managedConnection;
 
   private HashSet<Method> _myMethods = new HashSet<Method>();
 
-  public PxeConnectionImpl(Subject subject,
+  public OdeConnectionImpl(Subject subject,
       ConnectionRequestInfo connectionRequestInfo) {
     _subject = subject;
     _cri = connectionRequestInfo;
@@ -66,13 +66,13 @@
   /**
    * Associate with a managed conneciton, or clear the association.
    */
-  void associate(PxeManagedConnectionImpl mconn) {
+  void associate(OdeManagedConnectionImpl mconn) {
     _managedConnection = mconn;
   }
 
-  private final PxeManagedConnectionImpl mc() throws ResourceException {
+  private final OdeManagedConnectionImpl mc() throws ResourceException {
     if (_managedConnection == null)
-      throw new PxeConnectionException("Not connected.");
+      throw new OdeConnectionException("Not connected.");
 
     return _managedConnection;
   }
@@ -94,10 +94,10 @@
       return mc().getTransport().invokeConnectionMethod(methodSig, args);
     } catch (RuntimeException pe) {
       pe.printStackTrace();
-      throw new PxeConnectionException("Unexpected RuntimeException", pe);
+      throw new OdeConnectionException("Unexpected RuntimeException", pe);
     } catch (RemoteException re) {
       re.printStackTrace();
-      throw new PxeConnectionException("Unexpected RemoteException.", re);
+      throw new OdeConnectionException("Unexpected RemoteException.", re);
     } catch (InvocationTargetException ite) {
       throw ite.getTargetException();
     }

Modified: incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionManager.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionManager.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionManager.java (original)
+++ incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionManager.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.ra;
+package org.apache.ode.ra;
 
 import javax.resource.ResourceException;
 import javax.resource.spi.ConnectionManager;
@@ -13,12 +13,12 @@
 /**
  * Default {@link ConnectionManager} for use in non-managed environments.
  */
-class PxeConnectionManager implements ConnectionManager {
+class OdeConnectionManager implements ConnectionManager {
   private static final long serialVersionUID = 1L;
 
   public Object allocateConnection(ManagedConnectionFactory managedConnectionFactory, ConnectionRequestInfo connectionRequestInfo)
           throws ResourceException {
-    PxeManagedConnectionImpl managedConnection = (PxeManagedConnectionImpl) managedConnectionFactory.createManagedConnection(null, connectionRequestInfo);
+    OdeManagedConnectionImpl managedConnection = (OdeManagedConnectionImpl) managedConnectionFactory.createManagedConnection(null, connectionRequestInfo);
     return managedConnection.getConnection(null, connectionRequestInfo);
   }
 }

Modified: incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionRequestInfo.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionRequestInfo.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionRequestInfo.java (original)
+++ incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionRequestInfo.java Thu Jul 27 14:51:14 2006
@@ -3,9 +3,9 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.ra;
+package org.apache.ode.ra;
 
-import com.fs.pxe.ra.transports.PxeTransport;
+import org.apache.ode.ra.transports.OdeTransport;
 
 import java.util.Properties;
 
@@ -14,12 +14,12 @@
 /**
  * Information about a connection.
  */
-class PxeConnectionRequestInfo implements ConnectionRequestInfo {
-  PxeTransport transport;
+class OdeConnectionRequestInfo implements ConnectionRequestInfo {
+  OdeTransport transport;
   String url;
   final Properties properties = new Properties();
 
-  PxeConnectionRequestInfo(PxeTransport transport, String url) {
+  OdeConnectionRequestInfo(OdeTransport transport, String url) {
     this.transport = transport;
     this.url = url;
   }
@@ -29,7 +29,7 @@
   }
 
   public boolean equals(Object obj) {
-    PxeConnectionRequestInfo other = (PxeConnectionRequestInfo) obj;
+    OdeConnectionRequestInfo other = (OdeConnectionRequestInfo) obj;
     return transport.equals(other.transport) && url.equals(other.url) &&
                    properties.equals(other.properties);
   }

Modified: incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeManagedConnectionFactory.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeManagedConnectionFactory.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeManagedConnectionFactory.java (original)
+++ incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeManagedConnectionFactory.java Thu Jul 27 14:51:14 2006
@@ -3,10 +3,10 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.ra;
+package org.apache.ode.ra;
 
-import com.fs.pxe.ra.transports.PxeTransport;
-import com.fs.pxe.ra.transports.rmi.RMITransport;
+import org.apache.ode.ra.transports.OdeTransport;
+import org.apache.ode.ra.transports.rmi.RMITransport;
 
 import java.io.PrintWriter;
 import java.rmi.RemoteException;
@@ -22,14 +22,14 @@
 /**
  * JCA {@link ManagedConnectionFactory} implementation.
  */
-public class PxeManagedConnectionFactory implements ManagedConnectionFactory {
+public class OdeManagedConnectionFactory implements ManagedConnectionFactory {
   private static final long serialVersionUID = 1L;
   private PrintWriter _logWriter;
 
   /** Default connection request information. */
-  private PxeConnectionRequestInfo _defaultCRI = new PxeConnectionRequestInfo(null,"");
+  private OdeConnectionRequestInfo _defaultCRI = new OdeConnectionRequestInfo(null,"");
 
-  public PxeManagedConnectionFactory() {
+  public OdeManagedConnectionFactory() {
     try {
       setTransport(RMITransport.class.getName());
     } catch (ResourceException re) {
@@ -40,7 +40,7 @@
   public void setTransport(String transportClassName) throws ResourceException {
     try {
       Class tclass = Class.forName(transportClassName);
-      _defaultCRI.transport = (PxeTransport) tclass.newInstance();
+      _defaultCRI.transport = (OdeTransport) tclass.newInstance();
     } catch (IllegalAccessException e) {
       ResourceException re = new ResourceException("Class-access error for transport class \"" + transportClassName + "\". ", e);
       throw re;
@@ -68,21 +68,21 @@
   }
 
   public Object createConnectionFactory() throws ResourceException {
-    return new PxeConnectionFactoryImpl(this, new PxeConnectionManager());
+    return new OdeConnectionFactoryImpl(this, new OdeConnectionManager());
   }
 
   public Object createConnectionFactory(ConnectionManager connectionManager) throws ResourceException {
-    return new PxeConnectionFactoryImpl(this, connectionManager);
+    return new OdeConnectionFactoryImpl(this, connectionManager);
   }
 
   public ManagedConnection createManagedConnection(Subject subject, ConnectionRequestInfo connectionRequestInfo) throws ResourceException {
-    PxeConnectionRequestInfo cri = (PxeConnectionRequestInfo) (connectionRequestInfo != null ? connectionRequestInfo : _defaultCRI);
+    OdeConnectionRequestInfo cri = (OdeConnectionRequestInfo) (connectionRequestInfo != null ? connectionRequestInfo : _defaultCRI);
 
     if (cri.transport == null)
       throw new ResourceException("No transport.");
 
     try {
-      return new PxeManagedConnectionImpl(cri.transport.createPipe(cri.url, cri.properties), subject, connectionRequestInfo);
+      return new OdeManagedConnectionImpl(cri.transport.createPipe(cri.url, cri.properties), subject, connectionRequestInfo);
     } catch (RemoteException ex) {
       ResourceException re = new ResourceException("Unable to create connection: " + ex.getMessage(), ex);
       throw re;

Modified: incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeManagedConnectionImpl.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeManagedConnectionImpl.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeManagedConnectionImpl.java (original)
+++ incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeManagedConnectionImpl.java Thu Jul 27 14:51:14 2006
@@ -3,9 +3,9 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.ra;
+package org.apache.ode.ra;
 
-import com.fs.pxe.ra.transports.PxeTransportPipe;
+import org.apache.ode.ra.transports.OdeTransportPipe;
 
 import java.io.PrintWriter;
 import java.lang.reflect.Proxy;
@@ -21,22 +21,22 @@
 /**
  * JCA {@link ManagedConnection} implementation.
  */
-class PxeManagedConnectionImpl implements ManagedConnection {
-  private final List<PxeConnectionImpl> _connections = new ArrayList<PxeConnectionImpl>();
+class OdeManagedConnectionImpl implements ManagedConnection {
+  private final List<OdeConnectionImpl> _connections = new ArrayList<OdeConnectionImpl>();
   private final ConnectionEventListenerSupport _eventListenerSupport = new ConnectionEventListenerSupport();
 
-  private PxeConnectionImpl _activeConnection;
+  private OdeConnectionImpl _activeConnection;
   private PrintWriter _logWriter;
   private ConnectionRequestInfo _cri;
   private Subject _subject;
 
   /** Physical communication pipe. */
-  private PxeTransportPipe _transportPipe;
+  private OdeTransportPipe _transportPipe;
   private Class<?> _connectionClasses[];
 
-  PxeManagedConnectionImpl() {}
+  OdeManagedConnectionImpl() {}
 
-  public PxeManagedConnectionImpl(PxeTransportPipe pipe, Subject subject, ConnectionRequestInfo connectionRequestInfo) 
+  public OdeManagedConnectionImpl(OdeTransportPipe pipe, Subject subject, ConnectionRequestInfo connectionRequestInfo) 
   throws ResourceException {
     _transportPipe = pipe;
     _subject = subject;
@@ -61,7 +61,7 @@
       _activeConnection.associate(null);
     }
     _activeConnection = null;
-    _activeConnection = (PxeConnectionImpl) o;
+    _activeConnection = (OdeConnectionImpl) o;
     _activeConnection.associate(this);
   }
 
@@ -79,7 +79,7 @@
 
   public Object getConnection(Subject subject, ConnectionRequestInfo connectionRequestInfo)
     throws ResourceException {
-    PxeConnectionImpl conn = new PxeConnectionImpl(subject, connectionRequestInfo);
+    OdeConnectionImpl conn = new OdeConnectionImpl(subject, connectionRequestInfo);
     _connections.add(conn);
     _activeConnection = conn;
     conn.associate(this);
@@ -116,13 +116,13 @@
 
   /**
    * Called by connection handle to indicate it has been closed.
-   * @param pxeConnection
+   * @param odeConnection
    */
-  void connectionClosed(PxeConnectionImpl pxeConnection) {
+  void connectionClosed(OdeConnectionImpl odeConnection) {
     _eventListenerSupport.connectionClosed(new ConnectionEvent(this, ConnectionEvent.CONNECTION_CLOSED));
   }
 
-  PxeTransportPipe getTransport() {
+  OdeTransportPipe getTransport() {
     return _transportPipe;
   }
 }

Modified: incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/ServiceProviderSession.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/ServiceProviderSession.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/ServiceProviderSession.java (original)
+++ incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/ServiceProviderSession.java Thu Jul 27 14:51:14 2006
@@ -3,11 +3,11 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.ra;
+package org.apache.ode.ra;
 
 /**
  * Base interface accessible to all sessions returned from
- * {@link PxeConnection#createServiceProviderSession(String, Class)}.
+ * {@link OdeConnection#createServiceProviderSession(String, Class)}.
  */
 public interface ServiceProviderSession {
 

Modified: incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/package.html
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/package.html?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/package.html (original)
+++ incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/package.html Thu Jul 27 14:51:14 2006
@@ -1,11 +1,11 @@
 <html>
   <body>
     <p>The client connection interface (&quot;CCI&quot;) provides a
-    uniform mechanism for accessing services hosted inside the PXE
+    uniform mechanism for accessing services hosted inside the ODE
     container from objects outside the container. For example,
     through the CCI a client can connect to a running BPEL service
     to inspect the state of a process instance; similarly, a Servlet
-    may use the CCI to notify a PXE SOAP service that a new message
+    may use the CCI to notify a ODE SOAP service that a new message
     has arrived.</p>
     
     <p>The CCI supports marshalling of invocations for arbitrary

Modified: incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/transports/PxeTransport.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/transports/PxeTransport.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/transports/PxeTransportPipe.java (original)
+++ incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/transports/PxeTransportPipe.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.ra.transports;
+package org.apache.ode.ra.transports;
 
 import java.lang.reflect.InvocationTargetException;
 import java.rmi.Remote;
@@ -13,7 +13,7 @@
  * Implemented by a communication transport to represent a single communication
  * pipe between client and server.
  */
-public interface PxeTransportPipe extends Remote {
+public interface OdeTransportPipe extends Remote {
 
   /**
    * Get the names of the client-side connection interfaces. 

Modified: incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/transports/rmi/PxeRemote.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/transports/rmi/PxeRemote.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/transports/rmi/RMITransport.java (original)
+++ incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/transports/rmi/RMITransport.java Thu Jul 27 14:51:14 2006
@@ -1,7 +1,7 @@
-package com.fs.pxe.ra.transports.rmi;
+package org.apache.ode.ra.transports.rmi;
 
-import com.fs.pxe.ra.transports.PxeTransport;
-import com.fs.pxe.ra.transports.PxeTransportPipe;
+import org.apache.ode.ra.transports.OdeTransport;
+import org.apache.ode.ra.transports.OdeTransportPipe;
 
 import java.net.MalformedURLException;
 import java.rmi.Naming;
@@ -12,12 +12,12 @@
 /**
  * A very simple RMI-based communication transport.
  */
-public class RMITransport implements PxeTransport {
+public class RMITransport implements OdeTransport {
 
-  public PxeTransportPipe createPipe(String url, Properties properties) throws RemoteException {
-    PxeRemote remoteServer;
+  public OdeTransportPipe createPipe(String url, Properties properties) throws RemoteException {
+    OdeRemote remoteServer;
     try {
-      remoteServer = (PxeRemote) Naming.lookup(url);
+      remoteServer = (OdeRemote) Naming.lookup(url);
     } catch (MalformedURLException e) {
       throw new RemoteException("Invalid URL: "  + url, e);
     } catch (NotBoundException e) {

Modified: incubator/ode/scratch/pxe-iapi/jca-rar/etc/ra.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-rar/etc/ra.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-rar/etc/ra.xml (original)
+++ incubator/ode/scratch/pxe-iapi/jca-rar/etc/ra.xml Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
     xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
     xsi:schemaLocation="http://java.sun.com/xml/ns/j2ee 
                         http://java.sun.com/xml/ns/j2ee/connector_1_5.xsd" version="1.5">
-    <display-name>PXE Resource Adapter</display-name>
+    <display-name>ODE Resource Adapter</display-name>
     <vendor-name>Intalio, Inc.</vendor-name>
     <eis-type>RMI</eis-type>
     <resourceadapter-version>1.0</resourceadapter-version>
@@ -15,7 +15,7 @@
         <outbound-resourceadapter>
             <connection-definition>
                 <managedconnectionfactory-class>
-                    com.fs.pxe.ra.PxeManagedConnectionFactory
+                    org.apache.ode.ra.OdeManagedConnectionFactory
                 </managedconnectionfactory-class>
                 <config-property>
                     <config-property-name>URL</config-property-name>
@@ -23,11 +23,11 @@
                     <config-property-value>rmi://localhost:2099/MyDomain</config-property-value>
                 </config-property>
                 <connectionfactory-interface>
-                    com.fs.pxe.ra.PxeConnectionFactory</connectionfactory-interface>
+                    org.apache.ode.ra.OdeConnectionFactory</connectionfactory-interface>
                 <connectionfactory-impl-class>
-					com.fs.pxe.ra.PxeConnectionFactoryImpl </connectionfactory-impl-class>
-                <connection-interface> com.fs.pxe.ra.PxeConnection</connection-interface>
-                <connection-impl-class> com.fs.pxe.ra.PxeConnectionImpl</connection-impl-class>
+					org.apache.ode.ra.OdeConnectionFactoryImpl </connectionfactory-impl-class>
+                <connection-interface> org.apache.ode.ra.OdeConnection</connection-interface>
+                <connection-impl-class> org.apache.ode.ra.OdeConnectionImpl</connection-impl-class>
             </connection-definition>
             <transaction-support>NoTransaction</transaction-support>
         </outbound-resourceadapter>

Modified: incubator/ode/scratch/pxe-iapi/jca-rar/pom.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-rar/pom.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-rar/pom.xml (original)
+++ incubator/ode/scratch/pxe-iapi/jca-rar/pom.xml Thu Jul 27 14:51:14 2006
@@ -1,24 +1,24 @@
 <?xml version="1.0"?>
 <project>
-    <groupId>pxe</groupId>
-    <artifactId>pxe-jca-rar</artifactId>
-    <name>PXE :: Universal JCA Resource Adapter Archive (RAR)</name>
+    <groupId>ode</groupId>
+    <artifactId>ode-jca-rar</artifactId>
+    <name>ODE :: Universal JCA Resource Adapter Archive (RAR)</name>
     <modelVersion>4.0.0</modelVersion>
     <parent>
-        <groupId>pxe</groupId>
-        <artifactId>pxe</artifactId>
+        <groupId>ode</groupId>
+        <artifactId>ode</artifactId>
         <version>2.0-SNAPSHOT</version>
     </parent>
     <version>2.0-SNAPSHOT</version>
     <packaging>rar</packaging>
     <dependencies>
         <dependency>
-            <groupId>pxe</groupId>
-            <artifactId>pxe-utils</artifactId>
+            <groupId>ode</groupId>
+            <artifactId>ode-utils</artifactId>
         </dependency>
         <dependency>
-            <groupId>pxe</groupId>
-            <artifactId>pxe-jca-ra</artifactId>
+            <groupId>ode</groupId>
+            <artifactId>ode-jca-ra</artifactId>
         </dependency>
     </dependencies>
     <build>

Modified: incubator/ode/scratch/pxe-iapi/jca-server/.classpath
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-server/.classpath?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-server/.classpath (original)
+++ incubator/ode/scratch/pxe-iapi/jca-server/.classpath Thu Jul 27 14:51:14 2006
@@ -2,7 +2,7 @@
 <classpath>
 	<classpathentry kind="con" path="org.eclipse.jdt.launching.JRE_CONTAINER"/>
 	<classpathentry kind="src" path="src/main/java"/>
-	<classpathentry combineaccessrules="false" kind="src" path="/pxe-jca-ra"/>
-	<classpathentry combineaccessrules="false" kind="src" path="/pxe-utils"/>
+	<classpathentry combineaccessrules="false" kind="src" path="/ode-jca-ra"/>
+	<classpathentry combineaccessrules="false" kind="src" path="/ode-utils"/>
 	<classpathentry kind="output" path="bin"/>
 </classpath>

Modified: incubator/ode/scratch/pxe-iapi/jca-server/.project
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-server/.project?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-server/.project (original)
+++ incubator/ode/scratch/pxe-iapi/jca-server/.project Thu Jul 27 14:51:14 2006
@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <projectDescription>
-	<name>pxe-jca-server</name>
+	<name>ode-jca-server</name>
 	<comment></comment>
 	<projects>
 	</projects>

Modified: incubator/ode/scratch/pxe-iapi/jca-server/pom.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-server/pom.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-server/pom.xml (original)
+++ incubator/ode/scratch/pxe-iapi/jca-server/pom.xml Thu Jul 27 14:51:14 2006
@@ -1,24 +1,24 @@
 <project>
-    <artifactId>pxe-jca-server</artifactId>
-    <name>PXE :: Universal JCA Server</name>
+    <artifactId>ode-jca-server</artifactId>
+    <name>ODE :: Universal JCA Server</name>
     <description>Server-side implementation of a JCA connector.</description>
 
     <modelVersion>4.0.0</modelVersion>
     <parent>
-        <groupId>pxe</groupId>
-        <artifactId>pxe</artifactId>
+        <groupId>ode</groupId>
+        <artifactId>ode</artifactId>
         <version>2.0-SNAPSHOT</version>
     </parent>
-    <groupId>pxe</groupId>
+    <groupId>ode</groupId>
     <version>2.0-SNAPSHOT</version>
     <dependencies>
         <dependency>
-            <groupId>pxe</groupId>
-            <artifactId>pxe-utils</artifactId>
+            <groupId>ode</groupId>
+            <artifactId>ode-utils</artifactId>
         </dependency>
         <dependency>
-            <groupId>pxe</groupId>
-            <artifactId>pxe-jca-ra</artifactId>
+            <groupId>ode</groupId>
+            <artifactId>ode-jca-ra</artifactId>
         </dependency>
     </dependencies>
 </project>

Modified: incubator/ode/scratch/pxe-iapi/jca-server/src/main/java/org/apache/ode/jca/server/ConnectionProvider.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-server/src/main/java/org/apache/ode/jca/server/ConnectionProvider.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-server/src/main/java/org/apache/ode/jca/server/ConnectionProvider.java (original)
+++ incubator/ode/scratch/pxe-iapi/jca-server/src/main/java/org/apache/ode/jca/server/ConnectionProvider.java Thu Jul 27 14:51:14 2006
@@ -1,4 +1,4 @@
-package com.fs.pxe.jca.server;
+package org.apache.ode.jca.server;
 
 public interface ConnectionProvider {
   String[] getConnectionIntefaces();

Modified: incubator/ode/scratch/pxe-iapi/jca-server/src/main/java/org/apache/ode/jca/server/Interaction.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-server/src/main/java/org/apache/ode/jca/server/Interaction.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-server/src/main/java/org/apache/ode/jca/server/Interaction.java (original)
+++ incubator/ode/scratch/pxe-iapi/jca-server/src/main/java/org/apache/ode/jca/server/Interaction.java Thu Jul 27 14:51:14 2006
@@ -1,4 +1,4 @@
-package com.fs.pxe.jca.server;
+package org.apache.ode.jca.server;
 
 /**
  * Marker interface identifying an object as being an interaction object

Modified: incubator/ode/scratch/pxe-iapi/jca-server/src/main/java/org/apache/ode/jca/server/rmi/RmiPipeServerImpl.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-server/src/main/java/org/apache/ode/jca/server/rmi/RmiPipeServerImpl.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-server/src/main/java/org/apache/ode/jca/server/rmi/RmiPipeServerImpl.java (original)
+++ incubator/ode/scratch/pxe-iapi/jca-server/src/main/java/org/apache/ode/jca/server/rmi/RmiPipeServerImpl.java Thu Jul 27 14:51:14 2006
@@ -5,7 +5,7 @@
  */
 
 
-package com.fs.pxe.jca.server.rmi;
+package org.apache.ode.jca.server.rmi;
 
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
@@ -14,15 +14,15 @@
 import java.util.HashMap;
 import java.util.WeakHashMap;
 
-import com.fs.pxe.jca.server.Interaction;
-import com.fs.pxe.ra.transports.rmi.PxeTransportPipeRemote;
-import com.fs.utils.Reflect;
+import org.apache.ode.jca.server.Interaction;
+import org.apache.ode.ra.transports.rmi.OdeTransportPipeRemote;
+import org.apache.ode.utils.Reflect;
 
 
 /**
  * Implementation of an RMI-based transport pipe.
  */
-class RmiPipeServerImpl implements PxeTransportPipeRemote {
+class RmiPipeServerImpl implements OdeTransportPipeRemote {
 
   private RmiTransportServerImpl _server;
   private String[] _connectionClass;
@@ -31,7 +31,7 @@
   final long createTime = System.currentTimeMillis();
   long lastActivityTime = createTime;
 
-  PxeTransportPipeRemote remote;
+  OdeTransportPipeRemote remote;
   Object target;
   private WeakHashMap<Object,RmiPipeServerImpl> _interactions = new WeakHashMap<Object,RmiPipeServerImpl>();
 

Modified: incubator/ode/scratch/pxe-iapi/jca-server/src/main/java/org/apache/ode/jca/server/rmi/RmiTransportServerImpl.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-server/src/main/java/org/apache/ode/jca/server/rmi/RmiTransportServerImpl.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-server/src/main/java/org/apache/ode/jca/server/rmi/RmiTransportServerImpl.java (original)
+++ incubator/ode/scratch/pxe-iapi/jca-server/src/main/java/org/apache/ode/jca/server/rmi/RmiTransportServerImpl.java Thu Jul 27 14:51:14 2006
@@ -3,11 +3,11 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.jca.server.rmi;
+package org.apache.ode.jca.server.rmi;
 
-import com.fs.pxe.jca.server.ConnectionProvider;
-import com.fs.pxe.ra.transports.rmi.PxeRemote;
-import com.fs.pxe.ra.transports.rmi.PxeTransportPipeRemote;
+import org.apache.ode.jca.server.ConnectionProvider;
+import org.apache.ode.ra.transports.rmi.OdeRemote;
+import org.apache.ode.ra.transports.rmi.OdeTransportPipeRemote;
 
 import java.rmi.Remote;
 import java.rmi.RemoteException;
@@ -21,7 +21,7 @@
  * Server-side of the RMI transport. Manages a collection of communication
  * "pipes", each represented by its own remote object.
  */
-public class RmiTransportServerImpl implements PxeRemote {
+public class RmiTransportServerImpl implements OdeRemote {
   private List<RmiPipeServerImpl> _pipes = new ArrayList<RmiPipeServerImpl>();
   private int _port = 1099;
   private Remote _remote;
@@ -71,9 +71,9 @@
   }
 
 
-  public synchronized PxeTransportPipeRemote newPipe() throws RemoteException  {
+  public synchronized OdeTransportPipeRemote newPipe() throws RemoteException  {
     RmiPipeServerImpl pipe = new RmiPipeServerImpl(this, _connProvider.createConnectionObject(),_connProvider.getConnectionIntefaces());
-    PxeTransportPipeRemote remote = (PxeTransportPipeRemote) UnicastRemoteObject.exportObject(pipe,0);
+    OdeTransportPipeRemote remote = (OdeTransportPipeRemote) UnicastRemoteObject.exportObject(pipe,0);
     pipe.remote = remote;
     _pipes.add(pipe);
     return remote;

Modified: incubator/ode/scratch/pxe-iapi/minerva/pom.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/minerva/pom.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/minerva/pom.xml (original)
+++ incubator/ode/scratch/pxe-iapi/minerva/pom.xml Thu Jul 27 14:51:14 2006
@@ -1,15 +1,15 @@
 <?xml version="1.0"?>
 <project>
-  <groupId>pxe</groupId>
-  <artifactId>pxe-minerva</artifactId>
-  <name>PXE :: Minerva JDBC Pool</name>
+  <groupId>ode</groupId>
+  <artifactId>ode-minerva</artifactId>
+  <name>ODE :: Minerva JDBC Pool</name>
 
   <version>2.0-SNAPSHOT</version>
   <packaging>jar</packaging>
   <modelVersion>4.0.0</modelVersion>
   <parent>
-    <groupId>pxe</groupId>
-    <artifactId>pxe</artifactId>
+    <groupId>ode</groupId>
+    <artifactId>ode</artifactId>
     <version>2.0-SNAPSHOT</version>
   </parent>
 

Modified: incubator/ode/scratch/pxe-iapi/minerva/src/main/java/org/opentools/minerva/connector/jdbc/XAManagedConnectionFactory.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/minerva/src/main/java/org/opentools/minerva/connector/jdbc/XAManagedConnectionFactory.java?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/minerva/src/main/java/org/opentools/minerva/connector/jdbc/XAManagedConnectionFactory.java (original)
+++ incubator/ode/scratch/pxe-iapi/minerva/src/main/java/org/opentools/minerva/connector/jdbc/XAManagedConnectionFactory.java Thu Jul 27 14:51:14 2006
@@ -3,10 +3,10 @@
  *
  * $Log$
  * Revision 1.2  2005/09/12 13:47:10  holger
- * finally closing PXE-23
+ * finally closing ODE-23
  *
  * Revision 1.1.1.1  2005/05/20 18:15:38  prb
- * Initial import of PXE source code.
+ * Initial import of ODE source code.
  *
  * Revision 1.1  2004/04/27 18:49:44  jguinney
  * *** empty log message ***
@@ -183,8 +183,8 @@
 //                    try {
 //                        name = (String)it.next();
 //                        value = props.getProperty(name);
-//                        com.fs.utils.beans.PropertyHelper ph = 
-//                          new com.fs.utils.beans.PropertyHelper(cls);
+//                        org.apache.ode.utils.beans.PropertyHelper ph = 
+//                          new org.apache.ode.utils.beans.PropertyHelper(cls);
 //                        ph.setProperty(xads, name, value);
 //                        /*Method meth = cls.getMethod("set"+Character.toUpperCase(name.charAt(0))+name.substring(1),
 //                                                    new Class[]{String.class});

Modified: incubator/ode/scratch/pxe-iapi/naming/pom.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/naming/pom.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/naming/pom.xml (original)
+++ incubator/ode/scratch/pxe-iapi/naming/pom.xml Thu Jul 27 14:51:14 2006
@@ -1,21 +1,21 @@
 <?xml version="1.0"?>
 <project>
-    <groupId>pxe</groupId>
-    <artifactId>pxe-naming</artifactId>
-    <name>PXE :: Simple JNDI</name>
+    <groupId>ode</groupId>
+    <artifactId>ode-naming</artifactId>
+    <name>ODE :: Simple JNDI</name>
     <description>A very simple implementation of JNDI.</description>
 
     <modelVersion>4.0.0</modelVersion>
     <parent>
-        <groupId>pxe</groupId>
-        <artifactId>pxe</artifactId>
+        <groupId>ode</groupId>
+        <artifactId>ode</artifactId>
         <version>2.0-SNAPSHOT</version>
     </parent>
     <version>2.0-SNAPSHOT</version>
     <dependencies>
         <dependency>
-            <groupId>pxe</groupId>
-            <artifactId>pxe-utils</artifactId>
+            <groupId>ode</groupId>
+            <artifactId>ode-utils</artifactId>
         </dependency>
     </dependencies>
 </project>

Modified: incubator/ode/scratch/pxe-iapi/naming/src/main/java/com/fs/naming/BindingMapContextImpl.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/naming/src/main/java/com/fs/naming/BindingMapContextImpl.java?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/naming/src/main/java/com/fs/naming/BindingMapContextImpl.java (original)
+++ incubator/ode/scratch/pxe-iapi/naming/src/main/java/com/fs/naming/BindingMapContextImpl.java Thu Jul 27 14:51:14 2006
@@ -6,7 +6,7 @@
 package com.fs.naming;
 
 import com.fs.naming.mem.InMemoryBindingMapImpl;
-import com.fs.utils.msg.MessageBundle;
+import org.apache.ode.utils.msg.MessageBundle;
 
 import java.io.Serializable;
 import java.rmi.RemoteException;

Modified: incubator/ode/scratch/pxe-iapi/naming/src/main/java/com/fs/naming/NamingMessages.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/naming/src/main/java/com/fs/naming/NamingMessages.java?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/naming/src/main/java/com/fs/naming/NamingMessages.java (original)
+++ incubator/ode/scratch/pxe-iapi/naming/src/main/java/com/fs/naming/NamingMessages.java Thu Jul 27 14:51:14 2006
@@ -6,7 +6,7 @@
 
 package com.fs.naming;
 
-import com.fs.utils.msg.MessageBundle;
+import org.apache.ode.utils.msg.MessageBundle;
 
 import javax.naming.Name;
 

Modified: incubator/ode/scratch/pxe-iapi/naming/src/main/java/com/fs/naming/RemoteContextFactory.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/naming/src/main/java/com/fs/naming/RemoteContextFactory.java?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/naming/src/main/java/com/fs/naming/RemoteContextFactory.java (original)
+++ incubator/ode/scratch/pxe-iapi/naming/src/main/java/com/fs/naming/RemoteContextFactory.java Thu Jul 27 14:51:14 2006
@@ -5,7 +5,7 @@
  */
 package com.fs.naming;
 
-import com.fs.utils.msg.MessageBundle;
+import org.apache.ode.utils.msg.MessageBundle;
 
 import java.rmi.Naming;
 import java.util.Hashtable;

Modified: incubator/ode/scratch/pxe-iapi/pom.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/pom.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/pom.xml (original)
+++ incubator/ode/scratch/pxe-iapi/pom.xml Thu Jul 27 14:51:14 2006
@@ -1,34 +1,34 @@
 <?xml version="1.0"?>
 <project>
-    <groupId>pxe</groupId>
-    <artifactId>pxe</artifactId>
-    <name>PXE</name>
+    <groupId>ode</groupId>
+    <artifactId>ode</artifactId>
+    <name>ODE</name>
 
   <packaging>pom</packaging>
   <modelVersion>4.0.0</modelVersion>
   <version>2.0-SNAPSHOT</version>
-  <url>http://pxe.fivesight.com</url>
+  <url>http://ode.fivesight.com</url>
   <issueManagement>
     <system>jira</system>
-    <url>http://pxe.fivesight.com/jira/</url>
+    <url>http://ode.fivesight.com/jira/</url>
   </issueManagement>
   <licenses>
     <license>
       <name> Common Public License 1.0</name>
-      <url>http://pxe.fivesight.com/confluence/display/PXE/Common+Public+License+1.0</url>
+      <url>http://ode.fivesight.com/confluence/display/ODE/Common+Public+License+1.0</url>
       <distribution>repo</distribution>
     </license>
   </licenses>
 
     <scm>
-        <connection>scm:svn:svn://svn.intalio.org/pxe</connection>
-        <developerConnection>scm:svn:svn+ssh://svn.intalio.org/usr/local/svn/repos/pxe/trunk/pxe</developerConnection>
-        <url>http://svn.intalio.org/viewrep/PXE-svn</url>
+        <connection>scm:svn:svn://svn.intalio.org/ode</connection>
+        <developerConnection>scm:svn:svn+ssh://svn.intalio.org/usr/local/svn/repos/ode/trunk/ode</developerConnection>
+        <url>http://svn.intalio.org/viewrep/ODE-svn</url>
     </scm>
 
     <organization>
         <name>Intalio</name>
-        <url>http://pxe.intalio.org</url>
+        <url>http://ode.intalio.org</url>
     </organization>
 
 
@@ -40,15 +40,15 @@
         <vendor.copyright>(C)1999-2006 Intalio Inc - ALL RIGHTS RESERVED</vendor.copyright>
 
     <!--
-        Default PXE properties, these properties may be referenced in resources and the
+        Default ODE properties, these properties may be referenced in resources and the
 	like. -->
 
-        <pxe.default.http.port>8080</pxe.default.http.port>
-        <pxe.default.rmi.port>2099</pxe.default.rmi.port>
-        <pxe.default.jmx.port>8686</pxe.default.jmx.port>
-        <pxe.default.jmx.username>admin</pxe.default.jmx.username>
-        <pxe.default.jmx.password>admin</pxe.default.jmx.password>
-        <pxe.default.domain>MyDomain</pxe.default.domain>
+        <ode.default.http.port>8080</ode.default.http.port>
+        <ode.default.rmi.port>2099</ode.default.rmi.port>
+        <ode.default.jmx.port>8686</ode.default.jmx.port>
+        <ode.default.jmx.username>admin</ode.default.jmx.username>
+        <ode.default.jmx.password>admin</ode.default.jmx.password>
+        <ode.default.domain>MyDomain</ode.default.domain>
 
     <!--
 	|
@@ -96,7 +96,7 @@
 
 
   <!--|
-      | List of PXE modules to build
+      | List of ODE modules to build
       |
   -->
     <modules>
@@ -217,8 +217,8 @@
                         </execution>
                     </executions>
                     <configuration>
-                        <remoteRepositoryId>pxe</remoteRepositoryId>
-                        <remoteRepositoryUrl>scpexe://pxe.intalio.org/var/www/public/maven1</remoteRepositoryUrl>
+                        <remoteRepositoryId>ode</remoteRepositoryId>
+                        <remoteRepositoryUrl>scpexe://ode.intalio.org/var/www/public/maven1</remoteRepositoryUrl>
                     </configuration>
                 </plugin>
             </plugins>
@@ -234,9 +234,9 @@
     -->
     <repositories>
         <repository>
-            <id>pxe</id>
-            <name>PXE Maven2 repository</name>
-            <url>http://pxe.intalio.org/public/maven2</url>
+            <id>ode</id>
+            <name>ODE Maven2 repository</name>
+            <url>http://ode.intalio.org/public/maven2</url>
         </repository>
         <repository>
             <id>central</id>
@@ -269,9 +269,9 @@
     </repositories>
     <pluginRepositories>
         <pluginRepository>
-            <id>pxe</id>
-            <name>PXE Maven2 repository</name>
-            <url>http://pxe.intalio.org/public/maven2</url>
+            <id>ode</id>
+            <name>ODE Maven2 repository</name>
+            <url>http://ode.intalio.org/public/maven2</url>
         </pluginRepository>
         <!--pluginRepository>
             <id>codehaus</id>
@@ -292,14 +292,14 @@
     -->
     <distributionManagement>
         <repository>
-            <id>pxe-maven2</id>
-            <url>scpexe://pxe.intalio.org/var/www/public/maven2</url>
+            <id>ode-maven2</id>
+            <url>scpexe://ode.intalio.org/var/www/public/maven2</url>
         </repository>
 
         <snapshotRepository>
-            <id>pxe-maven2-snapshot</id>
-            <name>PXE Development Repository</name>
-            <url>scpexe://pxe.intalio.org/var/www/public/maven2</url>
+            <id>ode-maven2-snapshot</id>
+            <name>ODE Development Repository</name>
+            <url>scpexe://ode.intalio.org/var/www/public/maven2</url>
         </snapshotRepository>
     </distributionManagement>
 
@@ -307,168 +307,168 @@
         <dependencies>
 	
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-bpel-bom</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-bpel-bom</artifactId>
                 <version>${project.version}</version>
             </dependency>
 	
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-bootstrap</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-bootstrap</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-bpel-runtime</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-bpel-runtime</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-bpel-ql</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-bpel-ql</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-bpel-schemas</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-bpel-schemas</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-bpel-api</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-bpel-api</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-bpel-api-jca</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-bpel-api-jca</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-bpel-compiler</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-bpel-compiler</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-bpel-dd</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-bpel-dd</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-bpel-el-xpath10</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-bpel-el-xpath10</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-bpel-el-xpath20</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-bpel-el-xpath20</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-bpel-obj</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-bpel-obj</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-bpel-parser</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-bpel-parser</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-bpel-scripts</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-bpel-scripts</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-bpel-connector</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-bpel-connector</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-dao-hibernate</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-dao-hibernate</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-dao-hibernate-db-derby</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-dao-hibernate-db-derby</artifactId>
                 <version>${project.version}</version>
                 <type>tar</type>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-dao-memory</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-dao-memory</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-jacob</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-jacob</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-jbi</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-jbi</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-jbi-install</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-jbi-install</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-jca-ra</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-jca-ra</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-jca-server</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-jca-server</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-jca-rar</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-jca-rar</artifactId>
                 <version>${project.version}</version>
                 <type>rar</type>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-minerva</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-minerva</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-naming</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-naming</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-tools</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-tools</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-soap</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-soap</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-bpel-scheduler-quartz</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-bpel-scheduler-quartz</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-utils</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-utils</artifactId>
                 <version>${project.version}</version>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-tools-bin</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-tools-bin</artifactId>
                 <type>tar</type>
                 <version>${project.version}</version>
                 <classifier>tar</classifier>
             </dependency>
             <dependency>
-                <groupId>pxe</groupId>
-                <artifactId>pxe-examples</artifactId>
+                <groupId>ode</groupId>
+                <artifactId>ode-examples</artifactId>
                 <type>tar</type>
                 <version>${project.version}</version>
                 <classifier>tar</classifier>

Modified: incubator/ode/scratch/pxe-iapi/soap/pom.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/soap/pom.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/soap/pom.xml (original)
+++ incubator/ode/scratch/pxe-iapi/soap/pom.xml Thu Jul 27 14:51:14 2006
@@ -1,20 +1,20 @@
 <?xml version="1.0"?>
 <project>
-    <groupId>pxe</groupId>
-    <artifactId>pxe-soap</artifactId>
-    <name>PXE :: SOAP Processing Library</name>
+    <groupId>ode</groupId>
+    <artifactId>ode-soap</artifactId>
+    <name>ODE :: SOAP Processing Library</name>
 
     <modelVersion>4.0.0</modelVersion>
     <parent>
-        <groupId>pxe</groupId>
-        <artifactId>pxe</artifactId>
+        <groupId>ode</groupId>
+        <artifactId>ode</artifactId>
         <version>2.0-SNAPSHOT</version>
     </parent>
     <version>2.0-SNAPSHOT</version>
     <dependencies>
         <dependency>
-            <groupId>pxe</groupId>
-            <artifactId>pxe-utils</artifactId>
+            <groupId>ode</groupId>
+            <artifactId>ode-utils</artifactId>
         </dependency>
 
         <dependency>

Modified: incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/AbstractSoapBinding.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/AbstractSoapBinding.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/AbstractSoapBinding.java (original)
+++ incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/AbstractSoapBinding.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.soap.mapping;
+package org.apache.ode.soap.mapping;
 
 public abstract class AbstractSoapBinding {
 

Modified: incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/BasicProfileBindingViolation.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/BasicProfileBindingViolation.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/BasicProfileBindingViolation.java (original)
+++ incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/BasicProfileBindingViolation.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.soap.mapping;
+package org.apache.ode.soap.mapping;
 
 
 /**

Modified: incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/HttpSOAPWriter.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/HttpSOAPWriter.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/HttpSOAPWriter.java (original)
+++ incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/HttpSOAPWriter.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.soap.mapping;
+package org.apache.ode.soap.mapping;
 
 import java.util.Map;
 

Modified: incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/Messages.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/Messages.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SOAPReader.java (original)
+++ incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SOAPReader.java Thu Jul 27 14:51:14 2006
@@ -3,9 +3,9 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.soap.mapping;
+package org.apache.ode.soap.mapping;
 
-import com.fs.utils.DOMUtils;
+import org.apache.ode.utils.DOMUtils;
 
 import java.util.*;
 

Modified: incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SOAPWriter.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SOAPWriter.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SOAPWriter.java (original)
+++ incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SOAPWriter.java Thu Jul 27 14:51:14 2006
@@ -3,10 +3,10 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.soap.mapping;
+package org.apache.ode.soap.mapping;
 
-import com.fs.utils.msg.MessageBundle;
-import com.fs.utils.stl.CollectionsX;
+import org.apache.ode.utils.msg.MessageBundle;
+import org.apache.ode.utils.stl.CollectionsX;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.w3c.dom.Document;

Modified: incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/Soap11Constants.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/Soap11Constants.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/Soap11Constants.java (original)
+++ incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/Soap11Constants.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.soap.mapping;
+package org.apache.ode.soap.mapping;
 
 import javax.xml.namespace.QName;
 

Modified: incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SoapBindingException.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SoapBindingException.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SoapBindingException.java (original)
+++ incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SoapBindingException.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.soap.mapping;
+package org.apache.ode.soap.mapping;
 
 /**
  * Indicates a problem with the SOAP WSDL binding.

Modified: incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SoapBindingModel.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SoapBindingModel.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SoapBindingModel.java (original)
+++ incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SoapBindingModel.java Thu Jul 27 14:51:14 2006
@@ -3,10 +3,10 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.soap.mapping;
+package org.apache.ode.soap.mapping;
 
-import com.fs.utils.msg.MessageBundle;
-import com.fs.utils.stl.CollectionsX;
+import org.apache.ode.utils.msg.MessageBundle;
+import org.apache.ode.utils.stl.CollectionsX;
 
 import java.util.*;
 

Modified: incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SoapFormatException.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SoapFormatException.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SoapFormatException.java (original)
+++ incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SoapFormatException.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.soap.mapping;
+package org.apache.ode.soap.mapping;
 
 /**
  * Indicates problem with a SOAP payload.

Modified: incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SoapMessage.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SoapMessage.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SoapMessage.java (original)
+++ incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SoapMessage.java Thu Jul 27 14:51:14 2006
@@ -13,9 +13,9 @@
  * @version 1.0, Apr 30, 2004
  * 
  */
-package com.fs.pxe.soap.mapping;
+package org.apache.ode.soap.mapping;
 
-import com.fs.utils.DOMUtils;
+import org.apache.ode.utils.DOMUtils;
 
 import java.io.IOException;
 import java.io.InputStream;

Modified: incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SoapOperationBindingModel.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SoapOperationBindingModel.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SoapOperationBindingModel.java (original)
+++ incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SoapOperationBindingModel.java Thu Jul 27 14:51:14 2006
@@ -3,10 +3,10 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.soap.mapping;
+package org.apache.ode.soap.mapping;
 
-import com.fs.utils.msg.MessageBundle;
-import com.fs.utils.stl.CollectionsX;
+import org.apache.ode.utils.msg.MessageBundle;
+import org.apache.ode.utils.stl.CollectionsX;
 
 import java.util.*;
 

Modified: incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/package.html
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/package.html?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/package.html (original)
+++ incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/package.html Thu Jul 27 14:51:14 2006
@@ -1,11 +1,11 @@
 <html>
   <body>
     <p>SOAP Messaging Service Provider permits integration of the
-    PXE framework with external SOAP-based communication transports.
+    ODE framework with external SOAP-based communication transports.
     The provider is symmetric and provides both client and server
     functionality. The essential function of this component is to
     act as a bridge between external SOAP carrier protocols such as
-    HTTP and internal PXE channels.  This provider is capable of
+    HTTP and internal ODE channels.  This provider is capable of
     processing any SOAP message conforming to WS-I Basic Profile v1.0,
     and supports the detection of various hazard conditions that may
     occur in the presence of timeouts and non-transacted transport

Modified: incubator/ode/scratch/pxe-iapi/soap/test/junit/org/apache/ode/soap/mapping/SoapBindingModelTest.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/soap/test/junit/org/apache/ode/soap/mapping/SoapBindingModelTest.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/soap/test/junit/org/apache/ode/soap/mapping/SoapBindingModelTest.java (original)
+++ incubator/ode/scratch/pxe-iapi/soap/test/junit/org/apache/ode/soap/mapping/SoapBindingModelTest.java Thu Jul 27 14:51:14 2006
@@ -3,7 +3,7 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.soap.mapping;
+package org.apache.ode.soap.mapping;
 
 import java.net.URL;
 

Modified: incubator/ode/scratch/pxe-iapi/soap/test/junit/org/apache/ode/soap/mapping/SoapWriteReadTest.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/soap/test/junit/org/apache/ode/soap/mapping/SoapWriteReadTest.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/soap/test/junit/org/apache/ode/soap/mapping/SoapWriteReadTest.java (original)
+++ incubator/ode/scratch/pxe-iapi/soap/test/junit/org/apache/ode/soap/mapping/SoapWriteReadTest.java Thu Jul 27 14:51:14 2006
@@ -3,9 +3,9 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.soap.mapping;
+package org.apache.ode.soap.mapping;
 
-import com.fs.utils.DOMUtils;
+import org.apache.ode.utils.DOMUtils;
 
 import java.net.URL;
 import java.util.HashMap;
--- incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnection.java (original)
+++ incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnection.java Thu Jul 27 14:51:14 2006
@@ -3,24 +3,24 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.ra;
+package org.apache.ode.ra;
 
 import javax.resource.cci.Connection;
 
 /**
  * Interface providing access to a PXE domain from "external" entities such as
  * administrative consoles, protocol stacks, and client applications.
  */
-public interface PxeConnection extends Connection {
+public interface OdeConnection extends Connection {
 
   /**
    * Obtain access to a service provider belonging to this PXE domain through
    * its client session interface.
    *
    * @param serviceProviderUri URI of the Service Provider
    * @return possibly remote proxy to the Service Provider's client session interface.
    */
   public ServiceProviderSession createServiceProviderSession(String serviceProviderUri, Class sessionInterface)
-          throws PxeConnectionException;
+          throws OdeConnectionException;
 
 }
@@ -3,24 +3,24 @@
 
 /**
- * Interface providing access to a PXE domain from "external" entities such as
+ * Interface providing access to a ODE domain from "external" entities such as
  * administrative consoles, protocol stacks, and client applications.
  */
@@ -3,24 +3,24 @@
 
   /**
-   * Obtain access to a service provider belonging to this PXE domain through
+   * Obtain access to a service provider belonging to this ODE domain through
    * its client session interface.
    *

Modified: incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionException.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionException.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionException.java (original)
+++ incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionException.java Thu Jul 27 14:51:14 2006
@@ -3,21 +3,21 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.ra;
+package org.apache.ode.ra;
 
 import javax.resource.ResourceException;
 
 /**
  * Exception thrown in case of PXE communication failures.
  */
-public class PxeConnectionException extends ResourceException {
+public class OdeConnectionException extends ResourceException {
   private static final long serialVersionUID = 1L;
 
   /**
    * Constructor.
    * @param message the message
    */
-  PxeConnectionException(String message) {
+  OdeConnectionException(String message) {
     super(message);
   }
   
@@ -26,7 +26,7 @@
    * @param message the message
    * @param cause a <code>Throwable</code> cause for this exception
    */
-  PxeConnectionException(String message, Throwable cause) {
+  OdeConnectionException(String message, Throwable cause) {
     super(message);
     initCause(cause);
   }
@@ -35,7 +35,7 @@
    * Constructor.
    * @param cause a <code>Throwable</code> cause for this exception
    */
-  PxeConnectionException(Throwable cause) {
+  OdeConnectionException(Throwable cause) {
     super(cause.getMessage());
     initCause(cause);
   }
@@ -3,21 +3,21 @@
 
 /**
- * Exception thrown in case of PXE communication failures.
+ * Exception thrown in case of ODE communication failures.
  */

Modified: incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionFactory.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionFactory.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionFactory.java (original)
+++ incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionFactory.java Thu Jul 27 14:51:14 2006
@@ -3,13 +3,13 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.ra;
+package org.apache.ode.ra;
 
 import javax.resource.cci.ConnectionFactory;
 
 /**
  * Factory for obtaining {@link PxeConnection}s: the entry point for external
  * objects needing to access the PXE domain.
  */
-public interface PxeConnectionFactory extends ConnectionFactory {
+public interface OdeConnectionFactory extends ConnectionFactory {
 }
@@ -3,13 +3,13 @@
 
 /**
- * Factory for obtaining {@link PxeConnection}s: the entry point for external
- * objects needing to access the PXE domain.
+ * Factory for obtaining {@link OdeConnection}s: the entry point for external
+ * objects needing to access the ODE domain.
  */

Modified: incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionFactoryImpl.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/PxeConnectionFactoryImpl.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/transports/PxeTransport.java (original)
+++ incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/transports/PxeTransport.java Thu Jul 27 14:51:14 2006
@@ -3,16 +3,16 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.ra.transports;
+package org.apache.ode.ra.transports;
 
 import java.rmi.RemoteException;
 import java.util.Properties;
 
 
 /**
  * Interface implemented communication transports for the PXE JCA adapter.
  */
-public interface PxeTransport {
+public interface OdeTransport {
   
   /**
    * Create a new communication pipe.
@@ -21,7 +21,7 @@
    * @return new communication pipe
    * @throws RemoteException in case of communication failure
    */
-  public PxeTransportPipe createPipe(String url, Properties properties)
+  public OdeTransportPipe createPipe(String url, Properties properties)
           throws RemoteException ;
 
 }
@@ -3,16 +3,16 @@
 
 /**
- * Interface implemented communication transports for the PXE JCA adapter.
+ * Interface implemented communication transports for the ODE JCA adapter.
  */

Modified: incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/transports/PxeTransportPipe.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/transports/PxeTransportPipe.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/transports/rmi/PxeRemote.java (original)
+++ incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/transports/rmi/PxeRemote.java Thu Jul 27 14:51:14 2006
@@ -1,11 +1,11 @@
-package com.fs.pxe.ra.transports.rmi;
+package org.apache.ode.ra.transports.rmi;
 
 import java.rmi.Remote;
 import java.rmi.RemoteException;
 
 /**
  * RMI interface for remote PXE server.
  */
-public interface PxeRemote extends Remote {
-  public PxeTransportPipeRemote newPipe() throws RemoteException ;
+public interface OdeRemote extends Remote {
+  public OdeTransportPipeRemote newPipe() throws RemoteException ;
 }
@@ -1,11 +1,11 @@
 
 /**
- * RMI interface for remote PXE server.
+ * RMI interface for remote ODE server.
  */

Modified: incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/transports/rmi/PxeTransportPipeRemote.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/transports/rmi/PxeTransportPipeRemote.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/transports/rmi/PxeTransportPipeRemote.java (original)
+++ incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/transports/rmi/PxeTransportPipeRemote.java Thu Jul 27 14:51:14 2006
@@ -1,11 +1,11 @@
-package com.fs.pxe.ra.transports.rmi;
+package org.apache.ode.ra.transports.rmi;
 
-import com.fs.pxe.ra.transports.PxeTransportPipe;
+import org.apache.ode.ra.transports.OdeTransportPipe;
 
 import java.rmi.Remote;
 
 /**
  * RMI interface for a remote PXE connection listener.
  */
-public interface PxeTransportPipeRemote extends Remote, PxeTransportPipe {
+public interface OdeTransportPipeRemote extends Remote, OdeTransportPipe {
 }
@@ -1,11 +1,11 @@
 
 /**
- * RMI interface for a remote PXE connection listener.
+ * RMI interface for a remote ODE connection listener.
  */

Modified: incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/transports/rmi/RMITransport.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/jca-ra/src/main/java/org/apache/ode/ra/transports/rmi/RMITransport.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/Messages.java (original)
+++ incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/Messages.java Thu Jul 27 14:51:14 2006
@@ -3,14 +3,14 @@
  * Copyright: (C) 1999-2005 FiveSight Technologies Inc.
  *
  */
-package com.fs.pxe.soap.mapping;
+package org.apache.ode.soap.mapping;
 
 import javax.xml.namespace.QName;
 
-import com.fs.utils.msg.MessageBundle;
+import org.apache.ode.utils.msg.MessageBundle;
 
 /**
  * Message bundle for the <code>com.fs.pxe.soap.mapping</code> package.
  */
 public class Messages extends MessageBundle {
 
@@ -3,14 +3,14 @@
 
 /**
- * Message bundle for the <code>com.fs.pxe.soap.mapping</code> package.
+ * Message bundle for the <code>org.apache.ode.soap.mapping</code> package.
  */
 public class Messages extends MessageBundle {

Modified: incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SOAPReader.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/soap/src/java/org/apache/ode/soap/mapping/SOAPReader.java?rev=426260&r1=426245&r2=426260&view=diff
==============================================================================